# `pdag` — Parameter Directed Acyclic Graph

[![PyPI](https://img.shields.io/pypi/v/pdag)](https://pypi.org/project/pdag/)
<!-- [![conda-forge](https://img.shields.io/conda/vn/conda-forge/pdag.svg)](https://anaconda.org/conda-forge/pdag) -->
![PyPI - License](https://img.shields.io/pypi/l/pdag)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pdag)
![Test Status](https://github.com/shunichironomura/pdag/workflows/Test/badge.svg?event=push&branch=main)
[![codecov](https://codecov.io/gh/shunichironomura/pdag/graph/badge.svg?token=Hz2YE2769a)](https://codecov.io/gh/shunichironomura/pdag)
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pdag)

> [!WARNING]
> This package is under development.

## Tests

Run test with:

```bash
dotenvx run -f .env.pytest -- uv run pytest tests
```

or simply

```bash
PYTHONHASHSEED=0 uv run pytest tests
```
